# Generated by Django 4.2.11 on 2024-03-24 15:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0019_pdftype_cut_off_above_lines_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='pdftype',
            old_name='endoscopy_info_line',
            new_name='endoscope_info_line',
        ),
    ]
