# Generated by Django 4.2.11 on 2024-03-09 20:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0002_rawvideofile'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='frames_required',
            field=models.BooleanField(default=True),
        ),
    ]
