# Generated by Django 4.2.11 on 2024-03-09 17:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='RawVideoFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('uuid', models.UUIDField()),
                ('file', models.FileField(upload_to='raw_data/')),
                ('original_file_name', models.CharField(max_length=255)),
                ('hash', models.CharField(max_length=255, unique=True)),
                ('uploaded_at', models.DateTimeField(auto_now_add=True)),
                ('state_frames_extracted', models.BooleanField(default=False)),
                ('frame_dir', models.CharField(max_length=255)),
            ],
        ),
    ]
