# Generated by Django 4.2.11 on 2024-04-27 08:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0027_labvalue_abbreviation_labvalue_default_normal_range_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='unit',
            name='abbreviation',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
    ]
