# Generated by Django 4.2.11 on 2024-03-24 20:27

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0021_alter_pdftype_endoscope_info_line'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pdftype',
            name='endoscope_info_line',
            field=models.ForeignKey(default='', on_delete=django.db.models.deletion.CASCADE, related_name='pdf_type_endoscopy_info_line', to='endoreg_db.reportreaderflag'),
        ),
    ]
