# Generated by Django 4.2.13 on 2024-05-30 04:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0034_alter_rawpdffile_file'),
    ]

    operations = [
        migrations.AlterField(
            model_name='medicationindication',
            name='sources',
            field=models.ManyToManyField(blank=True, null=True, to='endoreg_db.informationsource'),
        ),
    ]
