# Generated by Django 4.2.11 on 2024-04-29 07:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0029_medicationintaketime_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='MedicationIndicationType',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('name_de', models.CharField(blank=True, max_length=255, null=True)),
                ('name_en', models.CharField(blank=True, max_length=255, null=True)),
            ],
        ),
        migrations.RemoveField(
            model_name='medicationintaketime',
            name='unit',
        ),
        migrations.AddField(
            model_name='informationsource',
            name='date',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='informationsource',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='informationsource',
            name='url',
            field=models.URLField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name',
            field=models.CharField(default=None, max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name_de',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationintaketime',
            name='name_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='dose',
            field=models.FloatField(default=1),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='name_de',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='name_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='medicationschedule',
            name='therapy_duration_d',
            field=models.DurationField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='patientlabvalue',
            name='normal_range',
            field=models.JSONField(default=dict),
        ),
        migrations.CreateModel(
            name='MedicationIndication',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('classification_choices', models.ManyToManyField(to='endoreg_db.diseaseclassificationchoice')),
                ('diseases', models.ManyToManyField(to='endoreg_db.disease')),
                ('events', models.ManyToManyField(to='endoreg_db.event')),
                ('indication_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.medicationindicationtype')),
                ('medication_schedules', models.ManyToManyField(to='endoreg_db.medicationschedule')),
            ],
        ),
    ]
