# Generated by Django 4.2.11 on 2024-04-29 07:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0030_medicationindicationtype_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='medication',
            old_name='adapt_to_liver_function',
            new_name='adapt_to_age',
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_hepatic_function',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_indication',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_risk',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='medication',
            name='adapt_to_weight',
            field=models.BooleanField(default=False),
        ),
    ]
