# Generated by Django 4.2.11 on 2024-06-09 11:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0047_casetemplaterule_target_model'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='chained_rules',
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='calling_rules',
            field=models.ManyToManyField(related_name='chained_rules', to='endoreg_db.casetemplaterule'),
        ),
    ]
