# Generated by Django 4.2.11 on 2024-03-24 10:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0015_rename_report_processed_rawpdffile_state_report_processed_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawpdffile',
            name='state_report_processing_required',
            field=models.BooleanField(default=True),
        ),
    ]
