# Generated by Django 4.2.11 on 2024-06-09 12:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0049_remove_casetemplaterule_rule_values'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='rule_values',
            field=models.ManyToManyField(related_name='rules', to='endoreg_db.casetemplaterulevalue'),
        ),
    ]
