# Generated by Django 4.2.11 on 2024-03-18 23:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0011_rawvideofile_state_sensitive_data_retrieved'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='prediction_dir',
            field=models.CharField(default='.', max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_anonym_video_performed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_anonym_video_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_dataset_complete',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_finalized',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_follow_up_intervention_available',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_follow_up_intervention_required',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_histology_available',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_histology_required',
            field=models.BooleanField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_import_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_import_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_initial_prediction_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_completed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_required',
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_ocr_result_validated',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_original_reports_deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_original_video_deleted',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='rawvideofile',
            name='state_outside_validated',
            field=models.BooleanField(default=False),
        ),
    ]
