# Generated by Django 5.0.4 on 2024-06-18 16:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0058_datevaluedistribution_description_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='rule_values',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
