# Generated by Django 4.2.11 on 2024-06-09 11:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0046_casetemplaterulevalue_target_field'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterule',
            name='target_model',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
