# Generated by Django 4.2.11 on 2024-04-29 07:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0032_alter_medicationschedule_therapy_duration_d'),
    ]

    operations = [
        migrations.AddField(
            model_name='medicationindication',
            name='sources',
            field=models.ManyToManyField(to='endoreg_db.informationsource'),
        ),
    ]
