# Generated by Django 4.2.11 on 2024-03-24 09:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0014_pdftype_alter_rawpdffile_file_pdfmeta'),
    ]

    operations = [
        migrations.RenameField(
            model_name='rawpdffile',
            old_name='report_processed',
            new_name='state_report_processed',
        ),
        migrations.AddField(
            model_name='rawpdffile',
            name='center',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='rawpdffile',
            name='pdf_type',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.pdftype'),
            preserve_default=False,
        ),
    ]
