# Generated by Django 4.2.11 on 2024-06-09 13:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0051_remove_casetemplaterule_calling_rules_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='casetemplate',
            old_name='case_template_type',
            new_name='template_type',
        ),
    ]
