# Generated by Django 4.2.11 on 2024-06-09 11:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0045_casetemplaterulevalue_value_type'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterulevalue',
            name='target_field',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
