# Generated by Django 4.2.11 on 2024-04-02 16:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0023_ttoquestionnaire_alter_pdftype_endoscope_info_line'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='ttoquestionnaire',
            name='infections',
        ),
        migrations.AddField(
            model_name='ttoquestionnaire',
            name='notes',
            field=models.TextField(default='Keine Bemerkungen', verbose_name='Bemerkungen'),
        ),
        migrations.AlterField(
            model_name='ttoquestionnaire',
            name='specimens_secured',
            field=models.BooleanField(default=False, verbose_name='Histologische Proben gesichert'),
        ),
    ]
