# Generated by Django 4.2.11 on 2024-06-09 11:23

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0044_casetemplateruletype_name_de_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='casetemplaterulevalue',
            name='value_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.casetemplaterulevaluetype'),
        ),
    ]
