# Generated by Django 5.0.4 on 2024-06-18 16:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0057_remove_datevaluedistribution_max_date_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='datevaluedistribution',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='name_de',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='name_en',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
