# Generated by Django 4.2.11 on 2024-03-10 15:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0006_rawvideofile_center_alter_videometa_processor'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='processor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscopyprocessor'),
        ),
    ]
