# Generated by Django 5.0.4 on 2024-06-10 20:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0055_remove_casetemplaterule_rule_values_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='DateValueDistribution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('min_date', models.DateField()),
                ('max_date', models.DateField()),
                ('distribution_type', models.CharField(choices=[('uniform', 'Uniform')], max_length=20)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_date_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.datevaluedistribution'),
        ),
    ]
