# Generated by Django 4.2.11 on 2024-04-27 07:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0026_disease_diseaseclassification_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='labvalue',
            name='abbreviation',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='default_normal_range',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_age_dependent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_gender_dependent',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='labvalue',
            name='normal_range_special_case',
            field=models.BooleanField(default=False),
        ),
    ]
