# Generated by Django 5.0.4 on 2024-06-10 19:51

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0054_multiplecategoricalvaluedistribution_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='casetemplaterule',
            name='rule_values',
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_multiple_categorical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.multiplecategoricalvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_numerical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.numericvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='_single_categorical_value_distribution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.singlecategoricalvaluedistribution'),
        ),
        migrations.AddField(
            model_name='casetemplaterule',
            name='parent_model',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='distribution_type',
            field=models.CharField(choices=[('single_categorical', 'single_categorical'), ('multiple_categorical', 'multiple_categorical'), ('numeric', 'numeric')], default='single_categorical', max_length=255),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='name_de',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='casetemplaterulevaluetype',
            name='name_en',
            field=models.CharField(max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='casetemplaterule',
            name='value_type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='endoreg_db.casetemplaterulevaluetype'),
        ),
    ]
