# Generated by Django 4.2.11 on 2024-03-10 14:46

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0005_ffmpegmeta_remove_videoimportmeta_center_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='rawvideofile',
            name='center',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.center'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='videometa',
            name='processor',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.endoscopyprocessor'),
        ),
    ]
