# Generated by Django 5.0.4 on 2024-06-18 15:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0056_datevaluedistribution_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='datevaluedistribution',
            name='max_date',
        ),
        migrations.RemoveField(
            model_name='datevaluedistribution',
            name='min_date',
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_max',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_mean',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_min',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='date_std_dev',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='mode',
            field=models.CharField(choices=[('date', 'Date'), ('timedelta', 'Timedelta')], default=None, max_length=20),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_max',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_mean',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_min',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='datevaluedistribution',
            name='timedelta_days_std_dev',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='datevaluedistribution',
            name='distribution_type',
            field=models.CharField(choices=[('uniform', 'Uniform'), ('normal', 'Normal')], max_length=20),
        ),
    ]
