# Generated by Django 4.2.11 on 2024-03-10 17:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0009_sensitivemeta_rawvideofile_sensitive_meta'),
    ]

    operations = [
        migrations.RenameField(
            model_name='sensitivemeta',
            old_name='endoscope_serial_number',
            new_name='endoscope_sn',
        ),
    ]
